searchNodes=[{"doc":"DescriptionThis is Elixir framework for running QuicTransport(WebTransport over QUIC) server.https://w3c.github.io/webtransport/https://tools.ietf.org/html/draft-vvv-webtransport-quic-02This library depends on cloudflare/quiche.quiche is written in Rust, so you need to prepare Rust compiler to build this library.ReQUIem requires Rustler to bridge between elixir and rust.Current quiche version is 0.6.0, and it supports draft-29 of quic-transport-protocol. (it also accepts draft-27 or draft-28 QUIC frames)NoteThis library is currently in an experimental phase.We plan to ensure its stability by conducting sufficient interoperability and performance tests in the future.Getting StartedResource preparationPrepare a server and set up DNS so that you can access the server with your domain name.Also, prepare the certificate chain and private key pem file to be used for that domain name.You can follow the same procedure as when dealing with TLS on a typical web server.Also, decide the port to use this time, and set the firewall etc. so that you can access the server via that port.Define your own handlerFirst of all, let's define your own handler.Write the use Requiem line as follows.lib/my_app/my_handler.exdefmodule MyApp.MyHandler do use Requiem, otp_app: :my_app endConfigurationPrepare the config file. In config/config.exs or config/releases.exs, Write as follows.Make sure that the certificate can be specified via an environment variable.import Config config :my_app, MyApp.MyHandler, host: &quot;0.0,0.0&quot;, port: 443, cert_chain: System.get_env(&quot;CERT_FILE&quot;), priv_key: System.get_env(&quot;PRIV_KEY&quot;), initial_max_data: 10_000_000, max_udp_payload_size: 1350, initial_max_stream_data_bidi_local: 1_000_000, initial_max_stream_data_bidi_remote: 1_000_000, initial_max_stream_data_uni: 1_000_000, initial_max_streams_uni: 10, initial_max_streams_bidi: 10, disable_active_migration: true, enable_early_data: true,Set it like this. There are many more parameters for config, but I won't explain them here. See Configuration for details.Put your handler into your application supervisorWhen you start the application, include the handler module that you just created in the child_spec definition of Supervisor.lib/my_app/application.exdefmodule MyApp do use Application def start(_type, _args) do [ # ..., MyApp.MyHandler ] |&gt; Supervisor.start_link([ strategy: :one_for_one, name: MyApp.Supervisor ]) end endNow let's launch the application.CERT_FILE=/path/to/cert PRIV_KEY=/path/to/priv_key mix run --no-haltHandler callbacksIf there are no problems with the config and other settings, this will start the application, but it is of no use at this point. The reason is that no callback is written in the Handler.Let's try to implement just printing the sent data to the standard output.lib/my_app/my_handler.exdefmodule MyApp.MyHandler do use Requiem, otp_app: :my_app @impl Requiem def handle_stream(_stream_id, data, conn, state) do IO.puts(data) {:ok, conn, state} end endIf you want to create an echo server that sends data directly back to the recipient, you can write the followingdefmodule MyApp.MyHandler do use Requiem, otp_app: :my_app @impl Requiem def handle_stream(stream_id, data, conn, state) do stream_send(stream_id, data) {:ok, conn, state} end endHowever, this implementation may fail depending on the value of stream_id. See Stream for details.Let's add a few more things.defmodule MyApp.MyHandler do use Requiem, otp_app: :my_app @impl Requiem def init(conn, client) do {:ok, conn, %{}} end @impl Requiem def handle_stream(stream_id, data, conn, state) do stream_send(stream_id, data) {:ok, conn, state} end @impl Requiem def handle_info(request, conn, state) do {:noreply, conn, state} end @impl Requiem def handle_cast(request, conn, state) do {:noreply, conn, state} end @impl Requiem def handle_call(request, from, conn, state) do {:reply, :ok, conn, state} end @impl Requiem def terminate(_reason, _conn, _state) do :ok end endIf you are familiar with GenServer, you will see familiar names in the list. There are some parameters that you may not have seen before, such as conn and client, but other than that, you can probably guess how it behaves.You can hook initialization and termination processes with init/2 and terminate/3, and receive inter-process messages with handle_info/3, handle_cast/3, and handle_call/4.In addition, handle_dgram/3 can handle received datagrams. To send a datagram, use dgram_send/1.defmodule MyApp.MyHandler do use Requiem, otp_app: :my_app @impl Requiem def init(conn, client) do {:ok, conn, %{}} end @impl Requiem def handle_stream(stream_id, data, conn, state) do stream_send(stream_id, data) {:ok, conn, state} end @impl Requiem def handle_dgram(data, conn, state) do dgram_send(data) {:ok, conn, state} end @impl Requiem def handle_info(request, conn, state) do {:noreply, conn, state} end @impl Requiem def handle_cast(request, conn, state) do {:noreply, conn, state} end @impl Requiem def handle_call(request, from, conn, state) do {:reply, :ok, conn, state} end @impl Requiem def terminate(_reason, _conn, _state) do :ok end endTo use datagrams, you need to set the enable_dgram config to true.config :my_app, MyApp.MyHandler, host: &quot;0.0,0.0&quot;, port: 443, cert_chain: System.get_env(&quot;CERT&quot;), priv_key: System.get_env(&quot;PRIV_KEY&quot;), max_idle_timeout: 50000, initial_max_data: 10_000_000, max_udp_payload_size: 1350, initial_max_stream_data_bidi_local: 1_000_000, initial_max_stream_data_bidi_remote: 1_000_000, initial_max_stream_data_uni: 1_000_000, initial_max_streams_uni: 10, initial_max_streams_bidi: 10, disable_active_migration: true, enable_early_data: true, enable_dgram: trueOnce you have done this, you can open the WebTransport example page in Google Chrome and try to interact with it.For more information on the various callbacks and the various functions that can be called from here, see Handler.ExamplesThis repository contains an example project that can be used as a reference. Check inside the examples directory.Handlerhttps://github.com/xflagstudio/requiem/wiki/HandlerConfigurationhttps://github.com/xflagstudio/requiem/wiki/Configuration","ref":"Requiem.html","title":"Requiem","type":"behaviour"},{"doc":"","ref":"Requiem.html#c:handle_call/4","title":"Requiem.handle_call/4","type":"callback"},{"doc":"","ref":"Requiem.html#c:handle_cast/3","title":"Requiem.handle_cast/3","type":"callback"},{"doc":"","ref":"Requiem.html#c:handle_dgram/3","title":"Requiem.handle_dgram/3","type":"callback"},{"doc":"","ref":"Requiem.html#c:handle_info/3","title":"Requiem.handle_info/3","type":"callback"},{"doc":"","ref":"Requiem.html#c:handle_stream/4","title":"Requiem.handle_stream/4","type":"callback"},{"doc":"","ref":"Requiem.html#c:init/2","title":"Requiem.init/2","type":"callback"},{"doc":"","ref":"Requiem.html#c:terminate/3","title":"Requiem.terminate/3","type":"callback"},{"doc":"","ref":"Requiem.html#t:terminate_reason/0","title":"Requiem.terminate_reason/0","type":"type"},{"doc":"","ref":"Requiem.Address.html","title":"Requiem.Address","type":"module"},{"doc":"","ref":"Requiem.Address.html#from_binary/1","title":"Requiem.Address.from_binary/1","type":"function"},{"doc":"","ref":"Requiem.Address.html#from_rust_peer/1","title":"Requiem.Address.from_rust_peer/1","type":"function"},{"doc":"","ref":"Requiem.Address.html#new/3","title":"Requiem.Address.new/3","type":"function"},{"doc":"","ref":"Requiem.Address.html#same?/2","title":"Requiem.Address.same?/2","type":"function"},{"doc":"","ref":"Requiem.Address.html#to_binary/1","title":"Requiem.Address.to_binary/1","type":"function"},{"doc":"","ref":"Requiem.Address.html#to_udp_header/1","title":"Requiem.Address.to_udp_header/1","type":"function"},{"doc":"","ref":"Requiem.Address.html#t:t/0","title":"Requiem.Address.t/0","type":"type"},{"doc":"","ref":"Requiem.AddressTable.html","title":"Requiem.AddressTable","type":"module"},{"doc":"","ref":"Requiem.AddressTable.html#delete/2","title":"Requiem.AddressTable.delete/2","type":"function"},{"doc":"","ref":"Requiem.AddressTable.html#init/1","title":"Requiem.AddressTable.init/1","type":"function"},{"doc":"","ref":"Requiem.AddressTable.html#insert/3","title":"Requiem.AddressTable.insert/3","type":"function"},{"doc":"","ref":"Requiem.AddressTable.html#lookup/2","title":"Requiem.AddressTable.lookup/2","type":"function"},{"doc":"","ref":"Requiem.ClientIndication.html","title":"Requiem.ClientIndication","type":"module"},{"doc":"","ref":"Requiem.ClientIndication.html#from_binary/1","title":"Requiem.ClientIndication.from_binary/1","type":"function"},{"doc":"","ref":"Requiem.ClientIndication.html#to_binary/1","title":"Requiem.ClientIndication.to_binary/1","type":"function"},{"doc":"","ref":"Requiem.ClientIndication.html#t:t/0","title":"Requiem.ClientIndication.t/0","type":"type"},{"doc":"Config helper module","ref":"Requiem.Config.html","title":"Requiem.Config","type":"module"},{"doc":"","ref":"Requiem.Config.html#check_key_existence/1","title":"Requiem.Config.check_key_existence/1","type":"function"},{"doc":"","ref":"Requiem.Config.html#get/2","title":"Requiem.Config.get/2","type":"function"},{"doc":"","ref":"Requiem.Config.html#get!/2","title":"Requiem.Config.get!/2","type":"function"},{"doc":"","ref":"Requiem.Config.html#init/2","title":"Requiem.Config.init/2","type":"function"},{"doc":"","ref":"Requiem.Config.html#store/2","title":"Requiem.Config.store/2","type":"function"},{"doc":"","ref":"Requiem.Config.html#t:config_key/0","title":"Requiem.Config.config_key/0","type":"type"},{"doc":"","ref":"Requiem.Connection.html","title":"Requiem.Connection","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Requiem.Connection.html#child_spec/1","title":"Requiem.Connection.child_spec/1","type":"function"},{"doc":"","ref":"Requiem.Connection.html#process_packet/3","title":"Requiem.Connection.process_packet/3","type":"function"},{"doc":"","ref":"Requiem.Connection.html#start_link/1","title":"Requiem.Connection.start_link/1","type":"function"},{"doc":"","ref":"Requiem.Connection.html#t:t/0","title":"Requiem.Connection.t/0","type":"type"},{"doc":"","ref":"Requiem.ConnectionID.html","title":"Requiem.ConnectionID","type":"module"},{"doc":"","ref":"Requiem.ConnectionID.html#generate_from_odcid/2","title":"Requiem.ConnectionID.generate_from_odcid/2","type":"function"},{"doc":"QUIC connection process registry","ref":"Requiem.ConnectionRegistry.html","title":"Requiem.ConnectionRegistry","type":"module"},{"doc":"Find a QUIC connection process by connection-id.","ref":"Requiem.ConnectionRegistry.html#lookup/2","title":"Requiem.ConnectionRegistry.lookup/2","type":"function"},{"doc":"Returns the registry name.","ref":"Requiem.ConnectionRegistry.html#name/1","title":"Requiem.ConnectionRegistry.name/1","type":"function"},{"doc":"Register a QUIC connection process with connection-id.","ref":"Requiem.ConnectionRegistry.html#register/2","title":"Requiem.ConnectionRegistry.register/2","type":"function"},{"doc":"Unregister a QUIC connection process.","ref":"Requiem.ConnectionRegistry.html#unregister/2","title":"Requiem.ConnectionRegistry.unregister/2","type":"function"},{"doc":"","ref":"Requiem.ConnectionState.html","title":"Requiem.ConnectionState","type":"module"},{"doc":"","ref":"Requiem.ConnectionState.html#create_new_stream_id/2","title":"Requiem.ConnectionState.create_new_stream_id/2","type":"function"},{"doc":"","ref":"Requiem.ConnectionState.html#forget_to_trap_exit/2","title":"Requiem.ConnectionState.forget_to_trap_exit/2","type":"function"},{"doc":"","ref":"Requiem.ConnectionState.html#new/4","title":"Requiem.ConnectionState.new/4","type":"function"},{"doc":"","ref":"Requiem.ConnectionState.html#should_delegate_exit?/2","title":"Requiem.ConnectionState.should_delegate_exit?/2","type":"function"},{"doc":"","ref":"Requiem.ConnectionState.html#trap_exit/2","title":"Requiem.ConnectionState.trap_exit/2","type":"function"},{"doc":"","ref":"Requiem.ConnectionState.html#t:t/0","title":"Requiem.ConnectionState.t/0","type":"type"},{"doc":"Supervisor for all QUIC connection.","ref":"Requiem.ConnectionSupervisor.html","title":"Requiem.ConnectionSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Requiem.ConnectionSupervisor.html#child_spec/1","title":"Requiem.ConnectionSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"Requiem.ConnectionSupervisor.html#create_connection/7","title":"Requiem.ConnectionSupervisor.create_connection/7","type":"function"},{"doc":"","ref":"Requiem.ConnectionSupervisor.html#lookup_connection/4","title":"Requiem.ConnectionSupervisor.lookup_connection/4","type":"function"},{"doc":"","ref":"Requiem.ConnectionSupervisor.html#start_child/1","title":"Requiem.ConnectionSupervisor.start_child/1","type":"function"},{"doc":"","ref":"Requiem.ConnectionSupervisor.html#start_link/1","title":"Requiem.ConnectionSupervisor.start_link/1","type":"function"},{"doc":"","ref":"Requiem.ConnectionSupervisor.html#terminate_child/2","title":"Requiem.ConnectionSupervisor.terminate_child/2","type":"function"},{"doc":"","ref":"Requiem.DispatcherRegistry.html","title":"Requiem.DispatcherRegistry","type":"module"},{"doc":"","ref":"Requiem.DispatcherRegistry.html#gather/2","title":"Requiem.DispatcherRegistry.gather/2","type":"function"},{"doc":"","ref":"Requiem.DispatcherRegistry.html#lookup/2","title":"Requiem.DispatcherRegistry.lookup/2","type":"function"},{"doc":"","ref":"Requiem.DispatcherRegistry.html#name/1","title":"Requiem.DispatcherRegistry.name/1","type":"function"},{"doc":"","ref":"Requiem.DispatcherRegistry.html#register/2","title":"Requiem.DispatcherRegistry.register/2","type":"function"},{"doc":"","ref":"Requiem.DispatcherRegistry.html#unregister/2","title":"Requiem.DispatcherRegistry.unregister/2","type":"function"},{"doc":"","ref":"Requiem.DispatcherSupervisor.html","title":"Requiem.DispatcherSupervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Requiem.DispatcherSupervisor.html#child_spec/1","title":"Requiem.DispatcherSupervisor.child_spec/1","type":"function"},{"doc":"","ref":"Requiem.DispatcherSupervisor.html#start_link/1","title":"Requiem.DispatcherSupervisor.start_link/1","type":"function"},{"doc":"","ref":"Requiem.DispatcherWorker.html","title":"Requiem.DispatcherWorker","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Requiem.DispatcherWorker.html#child_spec/1","title":"Requiem.DispatcherWorker.child_spec/1","type":"function"},{"doc":"","ref":"Requiem.DispatcherWorker.html#start_link/1","title":"Requiem.DispatcherWorker.start_link/1","type":"function"},{"doc":"","ref":"Requiem.DispatcherWorker.html#t:t/0","title":"Requiem.DispatcherWorker.t/0","type":"type"},{"doc":"","ref":"Requiem.ErrorCode.html","title":"Requiem.ErrorCode","type":"module"},{"doc":"","ref":"Requiem.ErrorCode.html#to_integer/1","title":"Requiem.ErrorCode.to_integer/1","type":"function"},{"doc":"","ref":"Requiem.ErrorCode.html#t:error_code/0","title":"Requiem.ErrorCode.error_code/0","type":"type"},{"doc":"","ref":"Requiem.ExceptionGuard.html","title":"Requiem.ExceptionGuard","type":"module"},{"doc":"","ref":"Requiem.ExceptionGuard.html#guard/2","title":"Requiem.ExceptionGuard.guard/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.html","title":"Requiem.QUIC","type":"module"},{"doc":"","ref":"Requiem.QUIC.html#init/3","title":"Requiem.QUIC.init/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.html#setup/1","title":"Requiem.QUIC.setup/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html","title":"Requiem.QUIC.Config","type":"module"},{"doc":"","ref":"Requiem.QUIC.Config.html#enable_dgram/4","title":"Requiem.QUIC.Config.enable_dgram/4","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#enable_early_data/1","title":"Requiem.QUIC.Config.enable_early_data/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#enable_hystart/2","title":"Requiem.QUIC.Config.enable_hystart/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#grease/2","title":"Requiem.QUIC.Config.grease/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#load_cert_chain_from_pem_file/2","title":"Requiem.QUIC.Config.load_cert_chain_from_pem_file/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#load_priv_key_from_pem_file/2","title":"Requiem.QUIC.Config.load_priv_key_from_pem_file/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#load_verify_locations_from_directory/2","title":"Requiem.QUIC.Config.load_verify_locations_from_directory/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#load_verify_locations_from_file/2","title":"Requiem.QUIC.Config.load_verify_locations_from_file/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_ack_delay_exponent/2","title":"Requiem.QUIC.Config.set_ack_delay_exponent/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_application_protos/2","title":"Requiem.QUIC.Config.set_application_protos/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_cc_algorithm_name/2","title":"Requiem.QUIC.Config.set_cc_algorithm_name/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_disable_active_migration/2","title":"Requiem.QUIC.Config.set_disable_active_migration/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_initial_max_data/2","title":"Requiem.QUIC.Config.set_initial_max_data/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_initial_max_stream_data_bidi_local/2","title":"Requiem.QUIC.Config.set_initial_max_stream_data_bidi_local/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_initial_max_stream_data_bidi_remote/2","title":"Requiem.QUIC.Config.set_initial_max_stream_data_bidi_remote/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_initial_max_stream_data_uni/2","title":"Requiem.QUIC.Config.set_initial_max_stream_data_uni/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_initial_max_streams_bidi/2","title":"Requiem.QUIC.Config.set_initial_max_streams_bidi/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_initial_max_streams_uni/2","title":"Requiem.QUIC.Config.set_initial_max_streams_uni/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_max_ack_delay/2","title":"Requiem.QUIC.Config.set_max_ack_delay/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_max_idle_timeout/2","title":"Requiem.QUIC.Config.set_max_idle_timeout/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#set_max_udp_payload_size/2","title":"Requiem.QUIC.Config.set_max_udp_payload_size/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.html#verify_peer/2","title":"Requiem.QUIC.Config.verify_peer/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.ALPN.html","title":"Requiem.QUIC.Config.ALPN","type":"module"},{"doc":"","ref":"Requiem.QUIC.Config.ALPN.html#encode/1","title":"Requiem.QUIC.Config.ALPN.encode/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Config.ALPN.html#encode_list/1","title":"Requiem.QUIC.Config.ALPN.encode_list/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html","title":"Requiem.QUIC.Connection","type":"module"},{"doc":"","ref":"Requiem.QUIC.Connection.html#accept/3","title":"Requiem.QUIC.Connection.accept/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html#close/4","title":"Requiem.QUIC.Connection.close/4","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html#dgram_send/2","title":"Requiem.QUIC.Connection.dgram_send/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html#is_closed?/1","title":"Requiem.QUIC.Connection.is_closed?/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html#on_packet/2","title":"Requiem.QUIC.Connection.on_packet/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html#on_timeout/1","title":"Requiem.QUIC.Connection.on_timeout/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Connection.html#stream_send/3","title":"Requiem.QUIC.Connection.stream_send/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html","title":"Requiem.QUIC.NIF","type":"module"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_enable_dgram/4","title":"Requiem.QUIC.NIF.config_enable_dgram/4","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_enable_early_data/1","title":"Requiem.QUIC.NIF.config_enable_early_data/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_enable_hystart/2","title":"Requiem.QUIC.NIF.config_enable_hystart/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_grease/2","title":"Requiem.QUIC.NIF.config_grease/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_load_cert_chain_from_pem_file/2","title":"Requiem.QUIC.NIF.config_load_cert_chain_from_pem_file/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_load_priv_key_from_pem_file/2","title":"Requiem.QUIC.NIF.config_load_priv_key_from_pem_file/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_load_verify_locations_from_directory/2","title":"Requiem.QUIC.NIF.config_load_verify_locations_from_directory/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_load_verify_locations_from_file/2","title":"Requiem.QUIC.NIF.config_load_verify_locations_from_file/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_ack_delay_exponent/2","title":"Requiem.QUIC.NIF.config_set_ack_delay_exponent/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_application_protos/2","title":"Requiem.QUIC.NIF.config_set_application_protos/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_cc_algorithm_name/2","title":"Requiem.QUIC.NIF.config_set_cc_algorithm_name/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_disable_active_migration/2","title":"Requiem.QUIC.NIF.config_set_disable_active_migration/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_initial_max_data/2","title":"Requiem.QUIC.NIF.config_set_initial_max_data/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_initial_max_stream_data_bidi_local/2","title":"Requiem.QUIC.NIF.config_set_initial_max_stream_data_bidi_local/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_initial_max_stream_data_bidi_remote/2","title":"Requiem.QUIC.NIF.config_set_initial_max_stream_data_bidi_remote/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_initial_max_stream_data_uni/2","title":"Requiem.QUIC.NIF.config_set_initial_max_stream_data_uni/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_initial_max_streams_bidi/2","title":"Requiem.QUIC.NIF.config_set_initial_max_streams_bidi/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_initial_max_streams_uni/2","title":"Requiem.QUIC.NIF.config_set_initial_max_streams_uni/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_max_ack_delay/2","title":"Requiem.QUIC.NIF.config_set_max_ack_delay/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_max_idle_timeout/2","title":"Requiem.QUIC.NIF.config_set_max_idle_timeout/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_set_max_udp_payload_size/2","title":"Requiem.QUIC.NIF.config_set_max_udp_payload_size/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#config_verify_peer/2","title":"Requiem.QUIC.NIF.config_verify_peer/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_accept/3","title":"Requiem.QUIC.NIF.connection_accept/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_close/5","title":"Requiem.QUIC.NIF.connection_close/5","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_dgram_send/3","title":"Requiem.QUIC.NIF.connection_dgram_send/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_is_closed/1","title":"Requiem.QUIC.NIF.connection_is_closed/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_on_packet/3","title":"Requiem.QUIC.NIF.connection_on_packet/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_on_timeout/2","title":"Requiem.QUIC.NIF.connection_on_timeout/2","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#connection_stream_send/4","title":"Requiem.QUIC.NIF.connection_stream_send/4","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#packet_build_buffer_create/0","title":"Requiem.QUIC.NIF.packet_build_buffer_create/0","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#packet_build_negotiate_version/3","title":"Requiem.QUIC.NIF.packet_build_negotiate_version/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#packet_build_retry/6","title":"Requiem.QUIC.NIF.packet_build_retry/6","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#packet_parse_header/1","title":"Requiem.QUIC.NIF.packet_parse_header/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#quic_init/3","title":"Requiem.QUIC.NIF.quic_init/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#socket_address_parts/1","title":"Requiem.QUIC.NIF.socket_address_parts/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#socket_close/1","title":"Requiem.QUIC.NIF.socket_close/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#socket_open/6","title":"Requiem.QUIC.NIF.socket_open/6","type":"function"},{"doc":"","ref":"Requiem.QUIC.NIF.html#socket_send/3","title":"Requiem.QUIC.NIF.socket_send/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.Packet.html","title":"Requiem.QUIC.Packet","type":"module"},{"doc":"","ref":"Requiem.QUIC.Packet.html#build_negotiate_version/3","title":"Requiem.QUIC.Packet.build_negotiate_version/3","type":"function"},{"doc":"","ref":"Requiem.QUIC.Packet.html#build_retry/6","title":"Requiem.QUIC.Packet.build_retry/6","type":"function"},{"doc":"","ref":"Requiem.QUIC.Packet.html#create_buffer/0","title":"Requiem.QUIC.Packet.create_buffer/0","type":"function"},{"doc":"","ref":"Requiem.QUIC.Packet.html#parse_header/1","title":"Requiem.QUIC.Packet.parse_header/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Socket.html","title":"Requiem.QUIC.Socket","type":"module"},{"doc":"","ref":"Requiem.QUIC.Socket.html#address_parts/1","title":"Requiem.QUIC.Socket.address_parts/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Socket.html#close/1","title":"Requiem.QUIC.Socket.close/1","type":"function"},{"doc":"","ref":"Requiem.QUIC.Socket.html#open/7","title":"Requiem.QUIC.Socket.open/7","type":"function"},{"doc":"","ref":"Requiem.QUIC.Socket.html#send/3","title":"Requiem.QUIC.Socket.send/3","type":"function"},{"doc":"","ref":"Requiem.RetryToken.html","title":"Requiem.RetryToken","type":"module"},{"doc":"","ref":"Requiem.RetryToken.html#create/4","title":"Requiem.RetryToken.create/4","type":"function"},{"doc":"","ref":"Requiem.RetryToken.html#validate/4","title":"Requiem.RetryToken.validate/4","type":"function"},{"doc":"","ref":"Requiem.RetryToken.Params.html","title":"Requiem.RetryToken.Params","type":"module"},{"doc":"","ref":"Requiem.RetryToken.Params.html#format/3","title":"Requiem.RetryToken.Params.format/3","type":"function"},{"doc":"","ref":"Requiem.RetryToken.Params.html#parse/1","title":"Requiem.RetryToken.Params.parse/1","type":"function"},{"doc":"","ref":"Requiem.RetryToken.Protector.html","title":"Requiem.RetryToken.Protector","type":"module"},{"doc":"","ref":"Requiem.RetryToken.Protector.html#decrypt/4","title":"Requiem.RetryToken.Protector.decrypt/4","type":"function"},{"doc":"","ref":"Requiem.RetryToken.Protector.html#derive_key_and_iv/2","title":"Requiem.RetryToken.Protector.derive_key_and_iv/2","type":"function"},{"doc":"","ref":"Requiem.RetryToken.Protector.html#encrypt/3","title":"Requiem.RetryToken.Protector.encrypt/3","type":"function"},{"doc":"","ref":"Requiem.StreamId.html","title":"Requiem.StreamId","type":"module"},{"doc":"","ref":"Requiem.StreamId.html#classify/1","title":"Requiem.StreamId.classify/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#is_bidi?/1","title":"Requiem.StreamId.is_bidi?/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#is_client_initiated?/1","title":"Requiem.StreamId.is_client_initiated?/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#is_readable?/1","title":"Requiem.StreamId.is_readable?/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#is_server_initiated?/1","title":"Requiem.StreamId.is_server_initiated?/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#is_uni?/1","title":"Requiem.StreamId.is_uni?/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#is_writable?/1","title":"Requiem.StreamId.is_writable?/1","type":"function"},{"doc":"","ref":"Requiem.StreamId.html#t:initiator/0","title":"Requiem.StreamId.initiator/0","type":"type"},{"doc":"","ref":"Requiem.StreamId.html#t:orientation/0","title":"Requiem.StreamId.orientation/0","type":"type"},{"doc":"Root supervisor for all Requiem process tree.","ref":"Requiem.Supervisor.html","title":"Requiem.Supervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Requiem.Supervisor.html#child_spec/1","title":"Requiem.Supervisor.child_spec/1","type":"function"},{"doc":"","ref":"Requiem.Supervisor.html#child_spec/2","title":"Requiem.Supervisor.child_spec/2","type":"function"},{"doc":"","ref":"Requiem.Supervisor.html#children/1","title":"Requiem.Supervisor.children/1","type":"function"},{"doc":"","ref":"Requiem.Supervisor.html#start_link/2","title":"Requiem.Supervisor.start_link/2","type":"function"},{"doc":"","ref":"Requiem.Tracer.html","title":"Requiem.Tracer","type":"module"},{"doc":"","ref":"Requiem.Tracer.html#trace/2","title":"Requiem.Tracer.trace/2","type":"macro"},{"doc":"","ref":"Requiem.Tracer.html#trace/3","title":"Requiem.Tracer.trace/3","type":"macro"},{"doc":"","ref":"Requiem.Transport.html","title":"Requiem.Transport","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Requiem.Transport.html#child_spec/1","title":"Requiem.Transport.child_spec/1","type":"function"},{"doc":"","ref":"Requiem.Transport.html#send/3","title":"Requiem.Transport.send/3","type":"function"},{"doc":"","ref":"Requiem.Transport.html#start_link/1","title":"Requiem.Transport.start_link/1","type":"function"},{"doc":"","ref":"Requiem.Transport.html#t:t/0","title":"Requiem.Transport.t/0","type":"type"}]